pub struct IncomingMessage {
pub jsonrpc: String,
pub id: Option<u64>,
pub method: Option<String>,
pub params: Option<Value>,
pub result: Option<Value>,
pub error: Option<RpcError>,
}Expand description
A raw incoming JSON-RPC message that can be classified as a response, notification, or an RPC call from the remote side.
Fields
jsonrpc: Stringid: Option<u64>method: Option<String>params: Option<Value>result: Option<Value>error: Option<RpcError>Implementations
Sourceimpl IncomingMessage
impl IncomingMessage
Sourcepub fn is_response(&self) -> bool
pub fn is_response(&self) -> bool
A response has no method and carries result or error.
Sourcepub fn is_notification(&self) -> bool
pub fn is_notification(&self) -> bool
A notification has a method but no id.
Sourcepub fn is_rpc_call(&self) -> bool
pub fn is_rpc_call(&self) -> bool
An RPC call from the remote side has both method and id.
Sourcepub fn into_response(self) -> Response
pub fn into_response(self) -> Response
Convert into a Response (only valid when [is_response] is true).